@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: djview.cpp,v 1.51 2007/11/06 13:19:11 leonb Exp $
+// $Id: djview.cpp,v 1.54 2007/12/31 20:09:40 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -140,9 +140,8 @@ usage()
 static void
 addDirectory(QStringList &dirs, QString path)
 {
-  QDir dir = path;
-  QString dirname = dir.canonicalPath();
-  if (dir.exists() && !dirs.contains(dirname))
+  QString dirname = QDir::cleanPath(path);
+  if (! dirs.contains(dirname))
     dirs << dirname;
 }
 
@@ -160,10 +159,6 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
   QTranslator *djviewTrans = new QTranslator(this);
   // - determine preferred languages
   QStringList langs; 
-#ifdef Q_WS_MAC
-  langs += QSettings(".", "globalPreferences")
-    .value("AppleLanguages").toStringList();
-#endif
   QString varLanguage = ::getenv("LANGUAGE");
   if (varLanguage.size())
     langs += varLanguage.toLower().split(":", QString::SkipEmptyParts);
@@ -177,6 +172,10 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
   if (varLcMessages.size())
     langs += varLcMessages;
 # endif
+#endif
+#ifdef Q_WS_MAC
+  langs += QSettings(".", "globalPreferences")
+    .value("AppleLanguages").toStringList();
 #endif
   QString qtLocale =  QLocale::system().name();
   if (qtLocale.size())
@@ -193,9 +192,9 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
   addDirectory(dirs, datadir + "/djview4");
 #endif
 #ifdef Q_WS_MAC
-  addDirectory(dirs, dirPath + "/Resources");
-  addDirectory(dirs, dirPath + "/../Resources");
-  addDirectory(dirs, dirPath + "/../../Resources");
+  addDirectory(dirs, dirPath + "/Resources/$LANG.lproj");
+  addDirectory(dirs, dirPath + "/../Resources/$LANG.lproj");
+  addDirectory(dirs, dirPath + "/../../Resources/$LANG.lproj");
 #endif
   addDirectory(dirs, dirPath + "/share/djvu/djview4");
   addDirectory(dirs, dirPath + "/share/djview4");
@@ -213,13 +212,11 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
     {
       foreach (QString dir, dirs)
         {
-#ifdef Q_WS_MAC
-          if (dir.endsWith("/Resources"))
-            dir += "/" + lang + ".lproj";
-#endif
-          if (! qtTransValid)
+          dir = dir.replace(QRegExp("\\$LANG(?!\\w)"),lang);
+          QDir qdir(dir);
+          if (! qtTransValid && qdir.exists())
             qtTransValid = qtTrans->load("qt_" + lang, dir, "_.-");
-          if (! djviewTransValid)
+          if (! djviewTransValid && qdir.exists())
             djviewTransValid= djviewTrans->load("djview_" + lang, dir, "_.-");
         }
       if (lang == "en") 
@@ -282,10 +279,6 @@ main(int argc, char *argv[])
 
   // Message verbosity
   qtDefaultHandler = qInstallMsgHandler(qtMessageHandler);
-#if QT_VERSION < 0x40100
-  verbose = true;
-  qWarning("Using Qt < 4.1.0 with prejudice.");
-#endif
 #ifdef Q_OS_UNIX
   const char *s = ::getenv("DJVIEW_VERBOSE");
   if (s && strcmp(s,"0"))
