@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewplugin.h,v 1.16 2007/07/11 03:27:27 leonb Exp $
+// $Id: qdjviewplugin.h,v 1.17 2007/12/31 20:09:40 leonb Exp $
 
 #ifndef QDJVIEWPLUGIN_H
 #define QDJVIEWPLUGIN_H
@@ -94,7 +94,7 @@ private:
   void reportError(int err);
   void streamCreated(Stream *s);
   void streamDestroyed(Stream *s);
-  Instance *findInstance(QDjView *djview);
+  Instance *findInstance(QWidget *widget);
   void getUrl(Instance *instance, QUrl url, QString target);
   void showStatus(Instance *instance, QString message);
   void continueExec();
