@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewsidebar.cpp,v 1.42 2007/11/06 16:30:26 leonb Exp $
+// $Id: qdjviewsidebar.cpp,v 1.46 2007/12/31 20:09:40 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -68,7 +68,6 @@
 
 
 
-
 // =======================================
 // QDJVIEWOUTLINE
 // =======================================
@@ -196,11 +195,14 @@ QDjViewOutline::fillItems(QTreeWidgetItem *root, miniexp_t expr)
           // fill item
           const char *name = miniexp_to_str(miniexp_car(s));
           const char *page = miniexp_to_str(miniexp_cadr(s));
-          QTreeWidgetItem *item = new QTreeWidgetItem(root);
-          item->setText(0, QString::fromUtf8(name));
           int pageno = -1;
           if (page[0]=='#' && page[1]!='+' && page[1]!='-')
             pageno = djview->pageNumber(QString::fromUtf8(page));
+          QTreeWidgetItem *item = new QTreeWidgetItem(root);
+          if (name && name[0])
+            item->setText(0, QString::fromUtf8(name));
+          else if (pageno >= 0)
+            item->setText(0, tr("Page %1").arg(djview->pageName(pageno)));
           item->setData(0, Qt::UserRole, pageno);
           item->setFlags(0);
           item->setWhatsThis(0, whatsThis());
@@ -349,17 +351,7 @@ QDjViewThumbnails::View::View(QDjViewThumbnails *widget)
   setMovement(QListView::Static);
   setResizeMode(QListView::Adjust);
   setSpacing(8);
-#if QT_VERSION >= 0x040100
   setUniformItemSizes(true);
-#endif
-#if QT_VERSION < 0x040100
-  // Hack to request thumbnail computations because
-  // we cannot do it efficiently in Model::makeData().
-  connect((QObject*)verticalScrollBar(), SIGNAL(sliderMoved(int)),
-          (QObject*)widget->model, SLOT(scheduleRefresh()) );
-  // Really too slow without this.
-  setLayoutMode(QListView::Batched);
-#endif
 }
 
 
@@ -588,14 +580,6 @@ QDjViewThumbnails::Model::makeIcon(int pageno) const
           painter.end();
           return QIcon(pixmap);
         }
-#if QT_VERSION >= 0x40100
-      // We know this is not a sizehint request because the
-      // sizehint code calls Model::data(Qt::SizeHintRole) first.
-      // Therefore it must be a paint request and we can
-      // safely request thumbnail calculations.
-      else if (ddjvu_thumbnail_status(*doc,pageno,0)==DDJVU_JOB_NOTSTARTED)
-        const_cast<Model*>(this)->scheduleRefresh();
-#endif
     }
   return icon;
 }
@@ -635,10 +619,8 @@ QDjViewThumbnails::Model::data(const QModelIndex &index, int role) const
               return widget->whatsThis();
             case Qt::UserRole:
               return pageno;
-#if QT_VERSION >= 0x040100
             case Qt::SizeHintRole:
               return makeHint(pageno);
-#endif
             default:
               break;
             }
@@ -931,10 +913,9 @@ QDjViewFind::Model::data(const QModelIndex &index, int role) const
             case Qt::DisplayRole:
               return info.name;
             case Qt::ToolTipRole:
-              if (info.hits <= 1)
-                return tr("%1 hit").arg(info.hits);
-              else
-                return tr("%1 hits").arg(info.hits);
+              if (info.hits == 1)
+                return tr("1 hit");
+              return tr("%n hits", 0, info.hits);
             case Qt::WhatsThisRole:
               return widget->whatsThis();
             default:
@@ -1001,10 +982,10 @@ QDjViewFind::Model::modelAdd(int pageno, int hits)
   RowInfo info;
   info.pageno = pageno;
   info.hits = hits;
-  if (hits <= 1)
-    info.name = tr("Page %1 (%2 hit)").arg(name).arg(hits);
+  if (hits == 1)
+    info.name = tr("Page %1 (1 hit)").arg(name);
   else
-    info.name = tr("Page %1 (%2 hits)").arg(name).arg(hits);
+    info.name = tr("Page %1 (%n hits)", 0, hits).arg(name);
   int lo = modelFind(pageno);
   if (lo < pages.size() && pages[lo].pageno == pageno)
     {
